@@ -1,10 +1,12 @@
 package Bio::MLST::Spreadsheet::Row;
 # ABSTRACT: Create a row representation of the ST results for a single fasta file.
-$Bio::MLST::Spreadsheet::Row::VERSION = '2.0.1510612';
+$Bio::MLST::Spreadsheet::Row::VERSION = '2.1.1534813';
 
 use Data::Dumper;
 use Text::CSV;
 
+use Bio::MLST::FilterAlleles qw(only_keep_alleles);
+
 use Moose;
 
 has 'sequence_type_obj'  => ( is => 'ro', isa => 'Bio::MLST::SequenceType',     required => 1 ); 
@@ -64,8 +66,7 @@ sub _build__allele_order {
   open( my $profile_fh, '<', $profile_path );
 
   my @alleles = @{$csv->getline($profile_fh)};
-  @alleles = grep { $_ ne 'ST' } @alleles;
-  @alleles = grep { $_ ne 'clonal_complex' } @alleles;
+  @alleles = @{only_keep_alleles(\@alleles)};
 
   my @fixed_alleles;
   foreach my $allele ( @alleles ){
@@ -183,7 +184,7 @@ Bio::MLST::Spreadsheet::Row - Create a row representation of the ST results for
 
 =head1 VERSION
 
-version 2.0.1510612
+version 2.1.1534813
 
 =head1 SYNOPSIS
 
